@@ -15,5 +15,7 @@ def get_maedeep_path():
             os.path.isdir(os.path.join(x, "parametric_models"))][0]
 
 def get_maedeep_model():
-    return os.path.join(get_maedeep_path(), "parametric_models", 
-                        "model_spec.json")
+    return os.path.join(get_maedeep_path(), "parametric_models", "model_spec.json")
+
+def get_maedeep_linear_model():
+    return os.path.join(get_maedeep_path(), "linear_models", "linear_model.h5")
